@@ -1,20 +1,26 @@
-import _ast
-from _ast import *
+from __future__ import absolute_import
+import ast
+from ast import *
 
 from rope.base import fscommands
 
+try:
+    unicode
+except NameError:
+    unicode = str
 
-def parse(source, filename='<string>'):
+
+def parse(source, filename="<string>"):
     # NOTE: the raw string should be given to `compile` function
     if isinstance(source, unicode):
         source = fscommands.unicode_to_file_data(source)
-    if '\r' in source:
-        source = source.replace('\r\n', '\n').replace('\r', '\n')
-    if not source.endswith('\n'):
-        source += '\n'
+    if b"\r" in source:
+        source = source.replace(b"\r\n", b"\n").replace(b"\r", b"\n")
+    if not source.endswith(b"\n"):
+        source += b"\n"
     try:
-        return compile(source, filename, 'exec', _ast.PyCF_ONLY_AST)
-    except (TypeError, ValueError), e:
+        return ast.parse(source, filename="<unknown>")
+    except (TypeError, ValueError) as e:
         error = SyntaxError()
         error.lineno = 1
         error.filename = filename
@@ -24,20 +30,20 @@ def parse(source, filename='<string>'):
 
 def walk(node, walker):
     """Walk the syntax tree"""
-    method_name = '_' + node.__class__.__name__
+    method_name = "_" + node.__class__.__name__
     method = getattr(walker, method_name, None)
     if method is not None:
-        if isinstance(node, _ast.ImportFrom) and node.module is None:
+        if isinstance(node, ast.ImportFrom) and node.module is None:
             # In python < 2.7 ``node.module == ''`` for relative imports
             # but for python 2.7 it is None. Generalizing it to ''.
-            node.module = ''
+            node.module = ""
         return method(node)
     for child in get_child_nodes(node):
         walk(child, walker)
 
 
 def get_child_nodes(node):
-    if isinstance(node, _ast.Module):
+    if isinstance(node, ast.Module):
         return node.body
     result = []
     if node._fields is not None:
@@ -45,9 +51,9 @@ def get_child_nodes(node):
             child = getattr(node, name)
             if isinstance(child, list):
                 for entry in child:
-                    if isinstance(entry, _ast.AST):
+                    if isinstance(entry, ast.AST):
                         result.append(entry)
-            if isinstance(child, _ast.AST):
+            if isinstance(child, ast.AST):
                 result.append(child)
     return result
 
@@ -64,7 +70,7 @@ def get_children(node):
     result = []
     if node._fields is not None:
         for name in node._fields:
-            if name in ['lineno', 'col_offset']:
+            if name in ["lineno", "col_offset"]:
                 continue
             child = getattr(node, name)
             result.append(child)
