@@ -1,9 +1,38 @@
+"""Files and folders in a project are represented as resource objects.
+
+Files and folders are access through `Resource` objects. `Resource` has
+two subclasses: `File` and `Folder`. What we care about is that
+refactorings and `rope.base.change.Change`s use resources.
+
+There are two options to create a `Resource` for a path in a project.
+Note that in these examples `path` is the path to a file or folder
+relative to the project's root. A project's root folder is represented
+by an empty string.
+
+  1) Use the `rope.base.Project.get_resource()` method. E.g.:
+
+       myresource = myproject.get_resource(path)
+
+
+  2) Use the `rope.base.libutils` module. `libutils` has a function
+     named `path_to_resource()`. It takes a project and a path:
+
+       from rope.base import libutils
+
+       myresource = libutils.path_to_resource(myproject, path)
+
+Once we have a `Resource`, we can retrieve information from it, like
+getting the path relative to the project's root (via `path`), reading
+from and writing to the resource, moving the resource, etc.
+"""
+
 import os
 import re
+import warnings
 
-import rope.base.change
-import rope.base.fscommands
+from rope.base import change
 from rope.base import exceptions
+from rope.base import fscommands
 
 
 class Resource(object):
@@ -15,13 +44,14 @@ class Resource(object):
 
     def move(self, new_location):
         """Move resource to `new_location`"""
-        self._perform_change(rope.base.change.MoveResource(self, new_location),
-                             'Moving <%s> to <%s>' % (self.path, new_location))
+        self._perform_change(
+            change.MoveResource(self, new_location),
+            "Moving <%s> to <%s>" % (self.path, new_location),
+        )
 
     def remove(self):
         """Remove resource from the project"""
-        self._perform_change(rope.base.change.RemoveResource(self),
-                             'Removing <%s>' % self.path)
+        self._perform_change(change.RemoveResource(self), "Removing <%s>" % self.path)
 
     def is_folder(self):
         """Return true if the resource is a folder"""
@@ -34,7 +64,7 @@ class Resource(object):
 
     @property
     def parent(self):
-        parent = '/'.join(self.path.split('/')[0:-1])
+        parent = "/".join(self.path.split("/")[0:-1])
         return self.project.get_folder(parent)
 
     @property
@@ -49,7 +79,7 @@ class Resource(object):
     @property
     def name(self):
         """Return the name of this resource"""
-        return self.path.split('/')[-1]
+        return self.path.split("/")[-1]
 
     @property
     def real_path(self):
@@ -66,7 +96,7 @@ class Resource(object):
         return hash(self.path)
 
     def _perform_change(self, change_, description):
-        changes = rope.base.change.ChangeSet(description)
+        changes = change.ChangeSet(description)
         changes.add_change(change_)
         self.project.do(changes)
 
@@ -75,17 +105,27 @@ class File(Resource):
     """Represents a file"""
 
     def __init__(self, project, name):
+        # from rope.base.project import Project
+        # self.project = Project()
         super(File, self).__init__(project, name)
 
     def read(self):
         data = self.read_bytes()
         try:
-            return rope.base.fscommands.file_data_to_unicode(data)
-        except UnicodeDecodeError, e:
+            return fscommands.file_data_to_unicode(data)
+        except UnicodeDecodeError as e:
             raise exceptions.ModuleDecodeError(self.path, e.reason)
 
     def read_bytes(self):
-        return open(self.real_path, 'rb').read()
+        if not hasattr(self.project.fscommands, "read"):
+            warnings.warn(
+                "FileSystemCommands should implement read() method",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            with open(self.real_path, "rb") as handle:
+                return handle.read()
+        return self.project.fscommands.read(self.real_path)
 
     def write(self, contents):
         try:
@@ -93,8 +133,9 @@ class File(Resource):
                 return
         except IOError:
             pass
-        self._perform_change(rope.base.change.ChangeContents(self, contents),
-                             'Writing file <%s>' % self.path)
+        self._perform_change(
+            change.ChangeContents(self, contents), "Writing file <%s>" % self.path
+        )
 
     def is_folder(self):
         return False
@@ -114,8 +155,12 @@ class Folder(Resource):
 
     def get_children(self):
         """Return the children of this folder"""
+        try:
+            children = os.listdir(self.real_path)
+        except OSError:
+            return []
         result = []
-        for name in os.listdir(self.real_path):
+        for name in children:
             try:
                 child = self.get_child(name)
             except exceptions.ResourceNotFoundError:
@@ -126,19 +171,21 @@ class Folder(Resource):
 
     def create_file(self, file_name):
         self._perform_change(
-            rope.base.change.CreateFile(self, file_name),
-            'Creating file <%s>' % self._get_child_path(file_name))
+            change.CreateFile(self, file_name),
+            "Creating file <%s>" % self._get_child_path(file_name),
+        )
         return self.get_child(file_name)
 
     def create_folder(self, folder_name):
         self._perform_change(
-            rope.base.change.CreateFolder(self, folder_name),
-            'Creating folder <%s>' % self._get_child_path(folder_name))
+            change.CreateFolder(self, folder_name),
+            "Creating folder <%s>" % self._get_child_path(folder_name),
+        )
         return self.get_child(folder_name)
 
     def _get_child_path(self, name):
         if self.path:
-            return self.path + '/' + name
+            return self.path + "/" + name
         else:
             return name
 
@@ -153,24 +200,23 @@ class Folder(Resource):
             return False
 
     def get_files(self):
-        return [resource for resource in self.get_children()
-                if not resource.is_folder()]
+        return [
+            resource for resource in self.get_children() if not resource.is_folder()
+        ]
 
     def get_folders(self):
-        return [resource for resource in self.get_children()
-                if resource.is_folder()]
+        return [resource for resource in self.get_children() if resource.is_folder()]
 
     def contains(self, resource):
         if self == resource:
             return False
-        return self.path == '' or resource.path.startswith(self.path + '/')
+        return self.path == "" or resource.path.startswith(self.path + "/")
 
     def create(self):
         self.parent.create_folder(self.name)
 
 
 class _ResourceMatcher(object):
-
     def __init__(self):
         self.patterns = []
         self._compiled_patterns = []
@@ -178,7 +224,7 @@ class _ResourceMatcher(object):
     def set_patterns(self, patterns):
         """Specify which resources to match
 
-        `patterns` is a `list` of `str`\s that can contain ``*`` and
+        `patterns` is a `list` of `str` that can contain ``*`` and
         ``?`` signs for matching resource names.
 
         """
@@ -186,18 +232,20 @@ class _ResourceMatcher(object):
         self.patterns = patterns
 
     def _add_pattern(self, pattern):
-        re_pattern = pattern.replace('.', '\\.').\
-            replace('*', '[^/]*').replace('?', '[^/]').\
-            replace('//', '/(.*/)?')
-        re_pattern = '^(.*/)?' + re_pattern + '(/.*)?$'
+        re_pattern = (
+            pattern.replace(".", "\\.")
+            .replace("*", "[^/]*")
+            .replace("?", "[^/]")
+            .replace("//", "/(.*/)?")
+        )
+        re_pattern = "^(.*/)?" + re_pattern + "(/.*)?$"
         self.compiled_patterns.append(re.compile(re_pattern))
 
     def does_match(self, resource):
         for pattern in self.compiled_patterns:
             if pattern.match(resource.path):
                 return True
-        path = os.path.join(resource.project.address,
-                            *resource.path.split('/'))
+        path = os.path.join(resource.project.address, *resource.path.split("/"))
         if os.path.islink(path):
             return True
         return False
