@@ -6,8 +6,7 @@ from rope.base.change import ChangeSet, ChangeContents
 from rope.base.exceptions import RefactoringError
 from rope.base.utils import pycompat
 from rope.base.utils.datastructures import OrderedSet
-from rope.refactor import (sourceutils, similarfinder,
-                           patchedast, suites, usefunction)
+from rope.refactor import sourceutils, similarfinder, patchedast, suites, usefunction
 
 
 # Extract refactoring has lots of special cases.  I tried to split it
@@ -38,8 +37,7 @@ class _ExtractRefactoring(object):
 
     kind_prefixes = {}
 
-    def __init__(self, project, resource, start_offset, end_offset,
-                 variable=False):
+    def __init__(self, project, resource, start_offset, end_offset, variable=False):
         self.project = project
         self.resource = resource
         self.start_offset = self._fix_start(resource.read(), start_offset)
@@ -71,13 +69,18 @@ class _ExtractRefactoring(object):
         extracted_name, kind = self._get_kind_from_name(extracted_name, kind)
 
         info = _ExtractInfo(
-            self.project, self.resource, self.start_offset, self.end_offset,
-            extracted_name, variable=self._get_kind(kind) == 'variable',
-            similar=similar, make_global=global_)
+            self.project,
+            self.resource,
+            self.start_offset,
+            self.end_offset,
+            extracted_name,
+            variable=self._get_kind(kind) == "variable",
+            similar=similar,
+            make_global=global_,
+        )
         info.kind = self._get_kind(kind)
         new_contents = _ExtractPerformer(info).extract()
-        changes = ChangeSet('Extract %s <%s>' % (info.kind,
-                                                 extracted_name))
+        changes = ChangeSet("Extract %s <%s>" % (info.kind, extracted_name))
         changes.add_change(ChangeContents(self.resource, new_contents))
         return changes
 
@@ -91,7 +94,7 @@ class _ExtractRefactoring(object):
     @staticmethod
     def _validate_kind_prefix(kind, selected_kind):
         if kind and kind != selected_kind:
-            raise RefactoringError("Kind and shorcut in name missmatch")
+            raise RefactoringError("Kind and shortcut in name mismatch")
 
     @classmethod
     def _get_kind(cls, kind):
@@ -99,7 +102,7 @@ class _ExtractRefactoring(object):
 
 
 class ExtractMethod(_ExtractRefactoring):
-    kind = 'method'
+    kind = "method"
     allowed_kinds = ("function", "method", "staticmethod", "classmethod")
     kind_prefixes = {"@": "classmethod", "$": "staticmethod"}
 
@@ -109,22 +112,23 @@ class ExtractMethod(_ExtractRefactoring):
 
 
 class ExtractVariable(_ExtractRefactoring):
-
     def __init__(self, *args, **kwds):
         kwds = dict(kwds)
-        kwds['variable'] = True
+        kwds["variable"] = True
         super(ExtractVariable, self).__init__(*args, **kwds)
 
-    kind = 'variable'
+    kind = "variable"
 
     def _get_kind(cls, kind):
         return cls.kind
 
+
 class _ExtractInfo(object):
     """Holds information about the extract to be performed"""
 
-    def __init__(self, project, resource, start, end, new_name,
-                 variable, similar, make_global):
+    def __init__(
+        self, project, resource, start, end, new_name, variable, similar, make_global
+    ):
         self.project = project
         self.resource = resource
         self.pymodule = project.get_pymodule(resource)
@@ -140,17 +144,23 @@ class _ExtractInfo(object):
         self.make_global = make_global
 
     def _init_parts(self, start, end):
-        self.region = (self._choose_closest_line_end(start),
-                       self._choose_closest_line_end(end, end=True))
+        self.region = (
+            self._choose_closest_line_end(start),
+            self._choose_closest_line_end(end, end=True),
+        )
 
         start = self.logical_lines.logical_line_in(
-            self.lines.get_line_number(self.region[0]))[0]
+            self.lines.get_line_number(self.region[0])
+        )[0]
         end = self.logical_lines.logical_line_in(
-            self.lines.get_line_number(self.region[1]))[1]
+            self.lines.get_line_number(self.region[1])
+        )[1]
         self.region_lines = (start, end)
 
-        self.lines_region = (self.lines.get_line_start(self.region_lines[0]),
-                             self.lines.get_line_end(self.region_lines[1]))
+        self.lines_region = (
+            self.lines.get_line_start(self.region_lines[0]),
+            self.lines.get_line_end(self.region_lines[1]),
+        )
 
     @property
     def logical_lines(self):
@@ -159,33 +169,36 @@ class _ExtractInfo(object):
     def _init_scope(self):
         start_line = self.region_lines[0]
         scope = self.global_scope.get_inner_scope_for_line(start_line)
-        if scope.get_kind() != 'Module' and scope.get_start() == start_line:
+        if scope.get_kind() != "Module" and scope.get_start() == start_line:
             scope = scope.parent
         self.scope = scope
         self.scope_region = self._get_scope_region(self.scope)
 
     def _get_scope_region(self, scope):
-        return (self.lines.get_line_start(scope.get_start()),
-                self.lines.get_line_end(scope.get_end()) + 1)
+        return (
+            self.lines.get_line_start(scope.get_start()),
+            self.lines.get_line_end(scope.get_end()) + 1,
+        )
 
     def _choose_closest_line_end(self, offset, end=False):
         lineno = self.lines.get_line_number(offset)
         line_start = self.lines.get_line_start(lineno)
         line_end = self.lines.get_line_end(lineno)
-        if self.source[line_start:offset].strip() == '':
+        if self.source[line_start:offset].strip() == "":
             if end:
                 return line_start - 1
             else:
                 return line_start
-        elif self.source[offset:line_end].strip() == '':
+        elif self.source[offset:line_end].strip() == "":
             return min(line_end, len(self.source))
         return offset
 
     @property
     def one_line(self):
-        return self.region != self.lines_region and \
-            (self.logical_lines.logical_line_in(self.region_lines[0]) ==
-             self.logical_lines.logical_line_in(self.region_lines[1]))
+        return self.region != self.lines_region and (
+            self.logical_lines.logical_line_in(self.region_lines[0])
+            == self.logical_lines.logical_line_in(self.region_lines[1])
+        )
 
     @property
     def global_(self):
@@ -193,24 +206,21 @@ class _ExtractInfo(object):
 
     @property
     def method(self):
-        return self.scope.parent is not None and \
-            self.scope.parent.get_kind() == 'Class'
+        return self.scope.parent is not None and self.scope.parent.get_kind() == "Class"
 
     @property
     def indents(self):
-        return sourceutils.get_indents(self.pymodule.lines,
-                                       self.region_lines[0])
+        return sourceutils.get_indents(self.pymodule.lines, self.region_lines[0])
 
     @property
     def scope_indents(self):
         if self.global_:
             return 0
-        return sourceutils.get_indents(self.pymodule.lines,
-                                       self.scope.get_start())
+        return sourceutils.get_indents(self.pymodule.lines, self.scope.get_start())
 
     @property
     def extracted(self):
-        return self.source[self.region[0]:self.region[1]]
+        return self.source[self.region[0] : self.region[1]]
 
     _cached_parsed_extraced = None
 
@@ -235,7 +245,9 @@ class _ExtractInfo(object):
     def returning_named_expr(self):
         """Does the extracted piece contains named expression/:= operator)"""
         if self._returning_named_expr is None:
-            self._returning_named_expr = usefunction._namedexpr_last(self._parsed_extracted)
+            self._returning_named_expr = usefunction._namedexpr_last(
+                self._parsed_extracted
+            )
         return self._returning_named_expr
 
 
@@ -253,7 +265,6 @@ class _ExtractCollector(object):
 
 
 class _ExtractPerformer(object):
-
     def __init__(self, info):
         self.info = info
         _ExceptionalConditionChecker()(self.info)
@@ -271,8 +282,7 @@ class _ExtractPerformer(object):
 
     def _replace_occurrences(self, content, extract_info):
         for match in extract_info.matches:
-            replacement = similarfinder.CodeTemplate(
-                extract_info.replacement_pattern)
+            replacement = similarfinder.CodeTemplate(extract_info.replacement_pattern)
             mapping = {}
             for name in replacement.get_names():
                 node = match.get_ast(name)
@@ -282,8 +292,7 @@ class _ExtractPerformer(object):
                 else:
                     mapping[name] = name
             region = match.get_region()
-            content.add_change(region[0], region[1],
-                               replacement.substitute(mapping))
+            content.add_change(region[0], region[1], replacement.substitute(mapping))
 
     def _collect_info(self):
         extract_collector = _ExtractCollector(self.info)
@@ -297,17 +306,26 @@ class _ExtractPerformer(object):
         finder = similarfinder.SimilarFinder(self.info.pymodule)
         matches = []
         for start, end in regions:
-            region_matches = finder.get_matches(collector.body_pattern,
-                                               collector.checks, start, end)
+            region_matches = finder.get_matches(
+                collector.body_pattern, collector.checks, start, end
+            )
             # Don't extract overlapping regions
             last_match_end = -1
             for region_match in region_matches:
+                if self.info.one_line and self._is_assignment(region_match):
+                    continue
                 start, end = region_match.get_region()
                 if last_match_end < start:
                     matches.append(region_match)
                     last_match_end = end
         collector.matches = matches
 
+    @staticmethod
+    def _is_assignment(region_match):
+        return isinstance(
+            region_match.ast, (ast.Attribute, ast.Subscript)
+        ) and isinstance(region_match.ast.ctx, ast.Store)
+
     def _where_to_search(self):
         if self.info.similar:
             if self.info.make_global or self.info.global_:
@@ -317,8 +335,10 @@ class _ExtractPerformer(object):
                 regions = []
                 method_kind = _get_function_kind(self.info.scope)
                 for scope in class_scope.get_scopes():
-                    if method_kind == 'method' and \
-                       _get_function_kind(scope) != 'method':
+                    if (
+                        method_kind == "method"
+                        and _get_function_kind(scope) != "method"
+                    ):
                         continue
                     start = self.info.lines.get_line_start(scope.get_start())
                     end = self.info.lines.get_line_end(scope.get_end())
@@ -328,8 +348,7 @@ class _ExtractPerformer(object):
                 if self.info.variable:
                     return [self.info.scope_region]
                 else:
-                    return [self.info._get_scope_region(
-                        self.info.scope.parent)]
+                    return [self.info._get_scope_region(self.info.scope.parent)]
         else:
             return [self.info.region]
 
@@ -340,8 +359,10 @@ class _ExtractPerformer(object):
             start_line = self.info.logical_lines.logical_line_in(start)[0]
             matched_lines.append(start_line)
         location_finder = _DefinitionLocationFinder(self.info, matched_lines)
-        collector.definition_location = (location_finder.find_lineno(),
-                                         location_finder.find_indents())
+        collector.definition_location = (
+            location_finder.find_lineno(),
+            location_finder.find_indents(),
+        )
 
     def _find_definition(self, collector):
         if self.info.variable:
@@ -355,7 +376,6 @@ class _ExtractPerformer(object):
 
 
 class _DefinitionLocationFinder(object):
-
     def __init__(self, info, matched_lines):
         self.info = info
         self.matched_lines = matched_lines
@@ -366,11 +386,14 @@ class _DefinitionLocationFinder(object):
     def find_lineno(self):
         if self.info.variable and not self.info.make_global:
             return self._get_before_line()
-        if self.info.make_global or self.info.global_:
+        if self.info.global_:
             toplevel = self._find_toplevel(self.info.scope)
             ast = self.info.pymodule.get_ast()
             newlines = sorted(self.matched_lines + [toplevel.get_end() + 1])
             return suites.find_visible(ast, newlines)
+        if self.info.make_global:
+            toplevel = self._find_toplevel(self.info.scope)
+            return toplevel.get_end() + 1
         return self._get_after_scope()
 
     def _find_toplevel(self, scope):
@@ -382,8 +405,7 @@ class _DefinitionLocationFinder(object):
 
     def find_indents(self):
         if self.info.variable and not self.info.make_global:
-            return sourceutils.get_indents(self.info.lines,
-                                           self._get_before_line())
+            return sourceutils.get_indents(self.info.lines, self._get_before_line())
         else:
             if self.info.global_ or self.info.make_global:
                 return 0
@@ -398,7 +420,6 @@ class _DefinitionLocationFinder(object):
 
 
 class _ExceptionalConditionChecker(object):
-
     def __call__(self, info):
         self.base_conditions(info)
         if info.one_line:
@@ -408,69 +429,78 @@ class _ExceptionalConditionChecker(object):
 
     def base_conditions(self, info):
         if info.region[1] > info.scope_region[1]:
-            raise RefactoringError('Bad region selected for extract method')
+            raise RefactoringError("Bad region selected for extract method")
         end_line = info.region_lines[1]
         end_scope = info.global_scope.get_inner_scope_for_line(end_line)
         if end_scope != info.scope and end_scope.get_end() != end_line:
-            raise RefactoringError('Bad region selected for extract method')
+            raise RefactoringError("Bad region selected for extract method")
         try:
             extracted = info.extracted
             if info.one_line:
-                extracted = '(%s)' % extracted
+                extracted = "(%s)" % extracted
             if _UnmatchedBreakOrContinueFinder.has_errors(extracted):
-                raise RefactoringError('A break/continue without having a '
-                                       'matching for/while loop.')
+                raise RefactoringError(
+                    "A break/continue without having a matching for/while loop."
+                )
         except SyntaxError:
-            raise RefactoringError('Extracted piece should '
-                                   'contain complete statements.')
+            raise RefactoringError(
+                "Extracted piece should contain complete statements."
+            )
 
     def one_line_conditions(self, info):
         if self._is_region_on_a_word(info):
-            raise RefactoringError('Should extract complete statements.')
+            raise RefactoringError("Should extract complete statements.")
         if info.variable and not info.one_line:
-            raise RefactoringError('Extract variable should not '
-                                   'span multiple lines.')
-        if usefunction._named_expr_count(info._parsed_extracted) - usefunction._namedexpr_last(info._parsed_extracted):
-            raise RefactoringError('Extracted piece cannot '
-                                   'contain named expression (:= operator).')
+            raise RefactoringError("Extract variable should not span multiple lines.")
+        if usefunction._named_expr_count(
+            info._parsed_extracted
+        ) - usefunction._namedexpr_last(info._parsed_extracted):
+            raise RefactoringError(
+                "Extracted piece cannot contain named expression (:= operator)."
+            )
 
     def multi_line_conditions(self, info):
-        node = _parse_text(info.source[info.region[0]:info.region[1]])
+        node = _parse_text(info.source[info.region[0] : info.region[1]])
         count = usefunction._return_count(node)
         extracted = info.extracted
         if count > 1:
-            raise RefactoringError('Extracted piece can have only one '
-                                   'return statement.')
+            raise RefactoringError(
+                "Extracted piece can have only one return statement."
+            )
         if usefunction._yield_count(node):
-            raise RefactoringError('Extracted piece cannot '
-                                   'have yield statements.')
-        if not hasattr(ast, 'PyCF_ALLOW_TOP_LEVEL_AWAIT') and _AsyncStatementFinder.has_errors(extracted):
-            raise RefactoringError('Extracted piece can only have async/await '
-                                   'statements if Rope is running on Python '
-                                   '3.8 or higher')
+            raise RefactoringError("Extracted piece cannot have yield statements.")
+        if not hasattr(
+            ast, "PyCF_ALLOW_TOP_LEVEL_AWAIT"
+        ) and _AsyncStatementFinder.has_errors(extracted):
+            raise RefactoringError(
+                "Extracted piece can only have async/await "
+                "statements if Rope is running on Python "
+                "3.8 or higher"
+            )
         if count == 1 and not usefunction._returns_last(node):
-            raise RefactoringError('Return should be the last statement.')
+            raise RefactoringError("Return should be the last statement.")
         if info.region != info.lines_region:
-            raise RefactoringError('Extracted piece should '
-                                   'contain complete statements.')
+            raise RefactoringError(
+                "Extracted piece should contain complete statements."
+            )
 
     def _is_region_on_a_word(self, info):
-        if info.region[0] > 0 and \
-                self._is_on_a_word(info, info.region[0] - 1) or \
-                self._is_on_a_word(info, info.region[1] - 1):
+        if (
+            info.region[0] > 0
+            and self._is_on_a_word(info, info.region[0] - 1)
+            or self._is_on_a_word(info, info.region[1] - 1)
+        ):
             return True
 
     def _is_on_a_word(self, info, offset):
         prev = info.source[offset]
-        if not (prev.isalnum() or prev == '_') or \
-           offset + 1 == len(info.source):
+        if not (prev.isalnum() or prev == "_") or offset + 1 == len(info.source):
             return False
         next = info.source[offset + 1]
-        return next.isalnum() or next == '_'
+        return next.isalnum() or next == "_"
 
 
 class _ExtractMethodParts(object):
-
     def __init__(self, info):
         self.info = info
         self.info_collector = self._create_info_collector()
@@ -487,19 +517,23 @@ class _ExtractMethodParts(object):
     def _check_constraints(self):
         if self._extracting_staticmethod() or self._extracting_classmethod():
             if not self.info.method:
-                raise RefactoringError("Cannot extract to staticmethod/classmethod outside class")
+                raise RefactoringError(
+                    "Cannot extract to staticmethod/classmethod outside class"
+                )
 
     def _extacting_from_staticmethod(self):
-        return self.info.method and _get_function_kind(self.info.scope) == "staticmethod"
+        return (
+            self.info.method and _get_function_kind(self.info.scope) == "staticmethod"
+        )
 
     def _extracting_from_classmethod(self):
         return self.info.method and _get_function_kind(self.info.scope) == "classmethod"
 
     def get_definition(self):
         if self.info.global_:
-            return '\n%s\n' % self._get_function_definition()
+            return "\n%s\n" % self._get_function_definition()
         else:
-            return '\n%s' % self._get_function_definition()
+            return "\n%s" % self._get_function_definition()
 
     def get_replacement_pattern(self):
         variables = []
@@ -517,29 +551,29 @@ class _ExtractMethodParts(object):
     def _get_body(self):
         result = sourceutils.fix_indentation(self.info.extracted, 0)
         if self.info.one_line:
-            result = '(%s)' % result
+            result = "(%s)" % result
         return result
 
     def _find_temps(self):
-        return usefunction.find_temps(self.info.project,
-                                      self._get_body())
+        return usefunction.find_temps(self.info.project, self._get_body())
 
     def get_checks(self):
         if self.info.method and not self.info.make_global:
-            if _get_function_kind(self.info.scope) == 'method':
+            if _get_function_kind(self.info.scope) == "method":
                 class_name = similarfinder._pydefined_to_str(
-                    self.info.scope.parent.pyobject)
-                return {self._get_self_name(): 'type=' + class_name}
+                    self.info.scope.parent.pyobject
+                )
+                return {self._get_self_name(): "type=" + class_name}
         return {}
 
     def _create_info_collector(self):
         zero = self.info.scope.get_start() - 1
         start_line = self.info.region_lines[0] - zero
         end_line = self.info.region_lines[1] - zero
-        info_collector = _FunctionInformationCollector(start_line, end_line,
-                                                       self.info.global_)
-        body = self.info.source[self.info.scope_region[0]:
-                                self.info.scope_region[1]]
+        info_collector = _FunctionInformationCollector(
+            start_line, end_line, self.info.global_
+        )
+        body = self.info.source[self.info.scope_region[0] : self.info.scope_region[1]]
         node = _parse_text(body)
         ast.walk(node, info_collector)
         return info_collector
@@ -550,20 +584,20 @@ class _ExtractMethodParts(object):
 
         result = []
         self._append_decorators(result)
-        result.append('def %s:\n' % self._get_function_signature(args))
+        result.append("def %s:\n" % self._get_function_signature(args))
         unindented_body = self._get_unindented_function_body(returns)
         indents = sourceutils.get_indent(self.info.project)
         function_body = sourceutils.indent_lines(unindented_body, indents)
         result.append(function_body)
-        definition = ''.join(result)
+        definition = "".join(result)
 
-        return definition + '\n'
+        return definition + "\n"
 
     def _append_decorators(self, result):
         if self._extracting_staticmethod():
-            result.append('@staticmethod\n')
+            result.append("@staticmethod\n")
         elif self._extracting_classmethod():
-            result.append('@classmethod\n')
+            result.append("@classmethod\n")
 
     def _extracting_classmethod(self):
         return self.info.kind == "classmethod"
@@ -573,23 +607,24 @@ class _ExtractMethodParts(object):
 
     def _get_function_signature(self, args):
         args = list(args)
-        prefix = ''
+        prefix = ""
         if self._extracting_method() or self._extracting_classmethod():
             self_name = self._get_self_name()
             if self_name is None:
-                raise RefactoringError('Extracting a method from a function '
-                                       'with no self argument.')
+                raise RefactoringError(
+                    "Extracting a method from a function with no self argument."
+                )
             if self_name in args:
                 args.remove(self_name)
             args.insert(0, self_name)
-        return prefix + self.info.new_name + \
-            '(%s)' % self._get_comma_form(args)
+        return prefix + self.info.new_name + "(%s)" % self._get_comma_form(args)
 
     def _extracting_method(self):
-        return  not self._extracting_staticmethod() and \
-                (self.info.method and \
-                    not self.info.make_global and \
-                    _get_function_kind(self.info.scope) == 'method')
+        return not self._extracting_staticmethod() and (
+            self.info.method
+            and not self.info.make_global
+            and _get_function_kind(self.info.scope) == "method"
+        )
 
     def _get_self_name(self):
         if self._extracting_classmethod():
@@ -604,95 +639,124 @@ class _ExtractMethodParts(object):
             return param_names[0]
 
     def _get_function_call(self, args):
-        return '{prefix}{name}({args})'.format(
+        return "{prefix}{name}({args})".format(
             prefix=self._get_function_call_prefix(args),
             name=self.info.new_name,
-            args=self._get_comma_form(args))
+            args=self._get_comma_form(args),
+        )
 
     def _get_function_call_prefix(self, args):
-        prefix = ''
+        prefix = ""
         if self.info.method and not self.info.make_global:
             if self._extracting_staticmethod() or self._extracting_classmethod():
-                prefix = self.info.scope.parent.pyobject.get_name() + '.'
+                prefix = self.info.scope.parent.pyobject.get_name() + "."
             else:
                 self_name = self._get_self_name()
                 if self_name in args:
                     args.remove(self_name)
-                prefix = self_name + '.'
+                prefix = self_name + "."
         return prefix
 
     def _get_comma_form(self, names):
-        return ', '.join(names)
+        return ", ".join(names)
 
     def _get_call(self):
         args = self._find_function_arguments()
         returns = self._find_function_returns()
-        call_prefix = ''
+        call_prefix = ""
         if returns and (not self.info.one_line or self.info.returning_named_expr):
-            assignment_operator = ' := ' if self.info.one_line else ' = '
+            assignment_operator = " := " if self.info.one_line else " = "
             call_prefix = self._get_comma_form(returns) + assignment_operator
         if self.info.returned:
-            call_prefix = 'return '
+            call_prefix = "return "
         return call_prefix + self._get_function_call(args)
 
     def _find_function_arguments(self):
         # if not make_global, do not pass any global names; they are
         # all visible.
         if self.info.global_ and not self.info.make_global:
-            return list(self.info_collector.read & self.info_collector.postread & self.info_collector.written)
+            return list(
+                self.info_collector.read
+                & self.info_collector.postread
+                & self.info_collector.written
+            )
         if not self.info.one_line:
-            result = (self.info_collector.prewritten &
-                      self.info_collector.read)
-            result |= (self.info_collector.prewritten &
-                       self.info_collector.postread &
-                       (self.info_collector.maybe_written -
-                        self.info_collector.written))
+            result = self.info_collector.prewritten & self.info_collector.read
+            result |= (
+                self.info_collector.prewritten
+                & self.info_collector.postread
+                & (self.info_collector.maybe_written - self.info_collector.written)
+            )
             return list(result)
         start = self.info.region[0]
         if start == self.info.lines_region[0]:
-            start = start + re.search('\\S', self.info.extracted).start()
-        function_definition = self.info.source[start:self.info.region[1]]
+            start = start + re.search("\\S", self.info.extracted).start()
+        function_definition = self.info.source[start : self.info.region[1]]
         read = _VariableReadsAndWritesFinder.find_reads_for_one_liners(
-            function_definition)
+            function_definition
+        )
         return list(self.info_collector.prewritten.intersection(read))
 
     def _find_function_returns(self):
         if self.info.one_line:
-            written = self.info_collector.written | \
-                self.info_collector.maybe_written
+            written = self.info_collector.written | self.info_collector.maybe_written
             return list(written & self.info_collector.postread)
 
         if self.info.returned:
             return []
-        written = self.info_collector.written | \
-            self.info_collector.maybe_written
+        written = self.info_collector.written | self.info_collector.maybe_written
         return list(written & self.info_collector.postread)
 
     def _get_unindented_function_body(self, returns):
         if self.info.one_line:
-            if self.info.returning_named_expr:
-                return 'return ' + '(' + _join_lines(self.info.extracted) + ')'
-            else:
-                return 'return ' + _join_lines(self.info.extracted)
-        extracted_body = self.info.extracted
-        unindented_body = sourceutils.fix_indentation(extracted_body, 0)
+            return self._get_one_line_function_body()
+        return self._get_multiline_function_body(returns)
+
+    def _get_multiline_function_body(self, returns):
+        unindented_body = sourceutils.fix_indentation(self.info.extracted, 0)
+        unindented_body = self._insert_globals(unindented_body)
         if returns:
-            unindented_body += '\nreturn %s' % self._get_comma_form(returns)
+            unindented_body += "\nreturn %s" % self._get_comma_form(returns)
         return unindented_body
 
+    def _get_one_line_function_body(self):
+        if self.info.returning_named_expr:
+            body = "return " + "(" + _join_lines(self.info.extracted) + ")"
+        else:
+            body = "return " + _join_lines(self.info.extracted)
+        return self._insert_globals(body)
+
+    def _insert_globals(self, unindented_body):
+        globals_in_body = self._get_globals_in_body(unindented_body)
+        globals_ = self.info_collector.globals_ & (
+            self.info_collector.written | self.info_collector.maybe_written
+        )
+        globals_ = globals_ - globals_in_body
+
+        if globals_:
+            unindented_body = "global {}\n{}".format(
+                ", ".join(globals_), unindented_body
+            )
+        return unindented_body
+
+    @staticmethod
+    def _get_globals_in_body(unindented_body):
+        node = _parse_text(unindented_body)
+        visitor = _GlobalFinder()
+        ast.walk(node, visitor)
+        return visitor.globals_
+
 
 class _ExtractVariableParts(object):
-
     def __init__(self, info):
         self.info = info
 
     def get_definition(self):
-        result = self.info.new_name + ' = ' + \
-            _join_lines(self.info.extracted) + '\n'
+        result = self.info.new_name + " = " + _join_lines(self.info.extracted) + "\n"
         return result
 
     def get_body_pattern(self):
-        return '(%s)' % self.info.extracted.strip()
+        return "(%s)" % self.info.extracted.strip()
 
     def get_replacement_pattern(self):
         return self.info.new_name
@@ -702,7 +766,6 @@ class _ExtractVariableParts(object):
 
 
 class _FunctionInformationCollector(object):
-
     def __init__(self, start, end, is_global):
         self.start = start
         self.end = end
@@ -715,6 +778,8 @@ class _FunctionInformationCollector(object):
         self.postwritten = OrderedSet()
         self.host_function = True
         self.conditional = False
+        self.globals_ = OrderedSet()
+        self.surrounded_by_loop = 0
         self.loop_depth = 0
 
     def _read_variable(self, name, lineno):
@@ -754,6 +819,9 @@ class _FunctionInformationCollector(object):
             for name in visitor.read - visitor.written:
                 self._read_variable(name, node.lineno)
 
+    def _Global(self, node):
+        self.globals_.add(*node.names)
+
     def _AsyncFunctionDef(self, node):
         self._FunctionDef(node)
 
@@ -776,6 +844,31 @@ class _FunctionInformationCollector(object):
     def _ClassDef(self, node):
         self._written_variable(node.name, node.lineno)
 
+    def _ListComp(self, node):
+        self._comp_exp(node)
+
+    def _GeneratorExp(self, node):
+        self._comp_exp(node)
+
+    def _SetComp(self, node):
+        self._comp_exp(node)
+
+    def _DictComp(self, node):
+        self._comp_exp(node)
+
+    def _comp_exp(self, node):
+        read = OrderedSet(self.read)
+        written = OrderedSet(self.written)
+        maybe_written = OrderedSet(self.maybe_written)
+
+        for child in ast.get_child_nodes(node):
+            ast.walk(child, self)
+
+        comp_names = set([name.target.id for name in node.generators])
+        self.read = self.read - comp_names | read
+        self.written = self.written - comp_names | written
+        self.maybe_written = self.maybe_written - comp_names | maybe_written
+
     def _If(self, node):
         self._handle_conditional_node(node)
 
@@ -819,8 +912,11 @@ class _FunctionInformationCollector(object):
 
 
 def _get_argnames(arguments):
-    result = [pycompat.get_ast_arg_arg(node) for node in arguments.args
-              if isinstance(node, pycompat.ast_arg_type)]
+    result = [
+        pycompat.get_ast_arg_arg(node)
+        for node in arguments.args
+        if isinstance(node, pycompat.ast_arg_type)
+    ]
     if arguments.vararg:
         result.append(pycompat.get_ast_arg_arg(arguments.vararg))
     if arguments.kwarg:
@@ -829,7 +925,6 @@ def _get_argnames(arguments):
 
 
 class _VariableReadsAndWritesFinder(object):
-
     def __init__(self):
         self.written = set()
         self.read = set()
@@ -852,7 +947,7 @@ class _VariableReadsAndWritesFinder(object):
 
     @staticmethod
     def find_reads_and_writes(code):
-        if code.strip() == '':
+        if code.strip() == "":
             return set(), set()
         node = _parse_text(code)
         visitor = _VariableReadsAndWritesFinder()
@@ -861,7 +956,7 @@ class _VariableReadsAndWritesFinder(object):
 
     @staticmethod
     def find_reads_for_one_liners(code):
-        if code.strip() == '':
+        if code.strip() == "":
             return set(), set()
         node = _parse_text(code)
         visitor = _VariableReadsAndWritesFinder()
@@ -872,7 +967,7 @@ class _VariableReadsAndWritesFinder(object):
 class _BaseErrorFinder(object):
     @classmethod
     def has_errors(cls, code):
-        if code.strip() == '':
+        if code.strip() == "":
             return False
         node = _parse_text(code)
         visitor = cls()
@@ -881,7 +976,6 @@ class _BaseErrorFinder(object):
 
 
 class _UnmatchedBreakOrContinueFinder(_BaseErrorFinder):
-
     def __init__(self):
         self.error = False
         self.loop_count = 0
@@ -898,7 +992,7 @@ class _UnmatchedBreakOrContinueFinder(_BaseErrorFinder):
             ast.walk(child, self)
         self.loop_count -= 1
         if node.orelse:
-            if isinstance(node.orelse,(list,tuple)):
+            if isinstance(node.orelse, (list, tuple)):
                 for node_ in node.orelse:
                     ast.walk(node_, self)
             else:
@@ -922,7 +1016,6 @@ class _UnmatchedBreakOrContinueFinder(_BaseErrorFinder):
 
 
 class _AsyncStatementFinder(_BaseErrorFinder):
-
     def __init__(self):
         self.error = False
 
@@ -939,6 +1032,14 @@ class _AsyncStatementFinder(_BaseErrorFinder):
         pass
 
 
+class _GlobalFinder(object):
+    def __init__(self):
+        self.globals_ = OrderedSet()
+
+    def _Global(self, node):
+        self.globals_.add(*node.names)
+
+
 def _get_function_kind(scope):
     return scope.pyobject.get_kind()
 
@@ -950,9 +1051,12 @@ def _parse_text(body):
     except SyntaxError:
         # needed to parse expression containing := operator
         try:
-            node = ast.parse('(' + body + ')')
+            node = ast.parse("(" + body + ")")
         except SyntaxError:
-            node = ast.parse('async def __rope_placeholder__():\n' + sourceutils.fix_indentation(body, 4))
+            node = ast.parse(
+                "async def __rope_placeholder__():\n"
+                + sourceutils.fix_indentation(body, 4)
+            )
             node.body = node.body[0].body
     return node
 
@@ -960,8 +1064,8 @@ def _parse_text(body):
 def _join_lines(code):
     lines = []
     for line in code.splitlines():
-        if line.endswith('\\'):
+        if line.endswith("\\"):
             lines.append(line[:-1].strip())
         else:
             lines.append(line.strip())
-    return ' '.join(lines)
+    return " ".join(lines)
