@@ -82,6 +82,7 @@ class _PatchingASTWalker(object):
     exec_close_paren_or_space = object()
     exec_in_or_comma = object()
     with_or_comma_context_manager = object()
+    empty_tuple = object()
 
     def __call__(self, node):
         method = getattr(self, "_" + node.__class__.__name__, None)
@@ -128,6 +129,8 @@ class _PatchingASTWalker(object):
                     )
                 elif child is self.Number:
                     region = self.source.consume_number()
+                elif child == self.empty_tuple:
+                    region = self.source.consume_empty_tuple()
                 elif child == "!=":
                     # INFO: This has been added to handle deprecated ``<>``
                     region = self.source.consume_not_equal()
@@ -844,7 +847,7 @@ class _PatchingASTWalker(object):
         if node.elts:
             self._handle(node, self._child_nodes(node.elts, ","), eat_parens=True)
         else:
-            self._handle(node, ["(", ")"])
+            self._handle(node, [self.empty_tuple])
 
     def _UnaryOp(self, node):
         children = self._get_op(node.op)
@@ -863,6 +866,10 @@ class _PatchingASTWalker(object):
             children.append(node.value)
         self._handle(node, children)
 
+    def _YieldFrom(self, node):
+        children = ["yield", "from", node.value]
+        self._handle(node, children)
+
     def _While(self, node):
         children = ["while", node.test, ":"]
         children.extend(node.body)
@@ -946,6 +953,9 @@ class _Source(object):
         repattern = _Source._number_pattern
         return self._consume_pattern(repattern)
 
+    def consume_empty_tuple(self):
+        return self._consume_pattern(re.compile(r"\(\s*\)"))
+
     def consume_not_equal(self):
         if _Source._not_equals_pattern is None:
             _Source._not_equals_pattern = re.compile(r"<>|!=")
