@@ -13,12 +13,6 @@ from ropetest import testutils
 
 
 class SourceLinesAdapterTest(unittest.TestCase):
-    def setUp(self):
-        super(SourceLinesAdapterTest, self).setUp()
-
-    def tearDown(self):
-        super(SourceLinesAdapterTest, self).tearDown()
-
     def test_source_lines_simple(self):
         to_lines = SourceLinesAdapter("line1\nline2\n")
         self.assertEqual("line1", to_lines.get_line(1))
@@ -51,17 +45,79 @@ class SourceLinesAdapterTest(unittest.TestCase):
 
 
 class WordRangeFinderTest(unittest.TestCase):
-    def setUp(self):
-        super(WordRangeFinderTest, self).setUp()
-
-    def tearDown(self):
-        super(WordRangeFinderTest, self).tearDown()
-
     def _find_primary(self, code, offset):
         word_finder = worder.Worder(code)
         result = word_finder.get_primary_at(offset)
         return result
 
+    def _annotated_code(self, annotated_code):
+        """
+        Split annotated code into raw code and annotation.
+
+        Odd lines in `annotated_code` is the actual Python code.
+
+        Even lines in `annotated_code` are single-char annotation for the
+        previous line.
+
+        The annotation may contain one extra character which annotates the
+        newline/end of line character.
+        """
+        code_lines = annotated_code.splitlines()[::2]
+        annotations_lines = annotated_code.splitlines()[1::2]
+        if len(annotations_lines) < len(code_lines):
+            annotations_lines.append("")
+        for idx, (line, line_ann) in enumerate(zip(code_lines, annotations_lines)):
+            newline_ann_char = 1  # for annotation of the end of line character
+            self.assertLessEqual(
+                len(line_ann),
+                len(line) + newline_ann_char,
+                msg="Extra character in annotations",
+            )
+            line_ann = line_ann.rstrip()
+            line_ann += " " * (len(line) - len(line_ann))
+            if len(line_ann) != len(line) + newline_ann_char:
+                line_ann += " "
+            self.assertEqual(len(line_ann), len(line) + newline_ann_char)
+            annotations_lines[idx] = line_ann
+        code, annotations = "\n".join(code_lines), "\n".join(annotations_lines)
+        if code[-1] != "\n":
+            annotations = annotations[:-1]
+        self.assertEqual(len(code) + code.count("\n"), len(annotations))
+        return code, annotations
+
+    def _make_offset_annotation(self, code, func):
+        """
+        Create annotation by calling `func(offset)` for every offset in `code`.
+
+        For example, when the annotated code looks like so:
+
+            import a.b.c.d
+                   ++++++++
+
+        This means that `func(offset)` returns True whenever offset points to
+        the 'a.b.c.d' part and returns False everywhere else.
+        """
+
+        def _annotation_char(offset):
+            ann_char = "+" if func(offset) else " "
+            if code[offset] == "\n":
+                ann_char = ann_char + "\n"
+            return ann_char
+
+        return "".join([_annotation_char(offset) for offset in range(len(code))])
+
+    def assert_equal_annotation(self, code, expected, actual):
+        if expected != actual:
+            msg = ["Annotation does not match:\n"]
+            for line, line_exp, line_actual in zip(
+                code.splitlines(), expected.splitlines(), actual.splitlines()
+            ):
+                msg.append("  " + line + "\n")
+                if line_exp != line_actual:
+                    msg.append("e " + line_exp + "\n")
+                    msg.append("a " + line_actual + "\n")
+            self.fail("".join(msg))
+
     def test_keyword_before_parens(self):
         code = dedent("""\
             if (a_var).an_attr:
@@ -224,7 +280,33 @@ class WordRangeFinderTest(unittest.TestCase):
         code = '"" + # var2.\n  var3'
         self.assertEqual("var3", self._find_primary(code, 21))
 
-    def test_import_statement_finding(self):
+    def test_is_import_statement(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            import a.b.c.d
+                   ++++++++
+            from a.b import c
+
+            import a.b.c.d as d
+                   +++++++++++++
+            from a.b import c as e
+
+            from a.b import (
+
+                abc
+
+            )
+
+            result = a.b.c.d.f()
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(code, word_finder.is_import_statement),
+        )
+
+    def test_is_import_statement_finding(self):
         code = dedent("""\
             import mod
             a_var = 10
@@ -233,7 +315,7 @@ class WordRangeFinderTest(unittest.TestCase):
         self.assertTrue(word_finder.is_import_statement(code.index("mod") + 1))
         self.assertFalse(word_finder.is_import_statement(code.index("a_var") + 1))
 
-    def test_import_statement_finding2(self):
+    def test_is_import_statement_finding2(self):
         code = dedent("""\
             import a.b.c.d
             result = a.b.c.d.f()
@@ -308,6 +390,120 @@ class WordRangeFinderTest(unittest.TestCase):
         word_finder = worder.Worder(code)
         self.assertTrue(word_finder.is_assigned_here(0))
 
+    def test_is_from_statement(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            import a.b.c.d
+
+            from a.b import c
+                 +++++++++++++
+            import a.b.c.d as d
+
+            from a.b import c as e
+                 ++++++++++++++++++
+            from a.b import (
+                 +++++++++++++
+                abc
+            ++++++++
+            )
+            ++
+            result = a.b.c.d.f()
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(code, word_finder.is_from_statement),
+        )
+
+    def test_is_from_statement_module(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            import a.b.c.d
+
+            from a.b import c
+                +++++
+            import a.b.c.d as d
+
+            from a.b import c as e
+                +++++
+            from a.b import (
+                +++++
+                abc
+
+            )
+
+            result = a.b.c.d.f()
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(code, word_finder.is_from_statement_module),
+        )
+
+    def test_is_import_statement_aliased_module(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            import a.b.c.d
+
+            from a.b import c
+
+            import a.b.c.d as d
+                   +++++++
+            from a.b import c as e
+
+            from a.b import (
+
+                abc
+
+            )
+
+            import mod1, \\
+
+                mod2 as c, mod3, mod4 as d
+               +++++            +++++
+            result = a.b.c.d.f()
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(
+                code, word_finder.is_import_statement_aliased_module
+            ),
+        )
+
+    def test_is_from_aliased(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            import a.b.c.d
+
+            from a.b import c
+
+            import a.b.c.d as d
+
+            from a.b import c as e
+                           ++
+            from a.b import (
+
+                abc
+
+            )
+
+            from a.b import mod1, \\
+
+                mod2 as c, mod3, mod4 as d
+               +++++            +++++
+            result = a.b.c.d.f()
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(code, word_finder.is_from_aliased),
+        )
+
     def test_is_from_with_from_import_and_multiline_parens(self):
         code = "from mod import \\\n  (f,\n  g, h)\n"
         word_finder = worder.Worder(code)
@@ -318,7 +514,31 @@ class WordRangeFinderTest(unittest.TestCase):
         word_finder = worder.Worder(code)
         self.assertTrue(word_finder.is_from_statement(code.rindex("g")))
 
-    def test_one_letter_function_keyword_arguments(self):
+    def test_is_function_keyword_parameter(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            func(param=1)
+                ++++++
+            func(
+
+                param=1
+               ++++++
+            )
+
+            def func(param=1):
+                    ++++++
+                pass
+
+        """))
+        word_finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(
+                code, word_finder.is_function_keyword_parameter
+            ),
+        )
+
+    def test_one_letter_is_function_keyword_parameter(self):
         code = "f(p=1)\n"
         word_finder = worder.Worder(code)
         index = code.rindex("p")
@@ -362,7 +582,20 @@ class WordRangeFinderTest(unittest.TestCase):
             code.index("("), finder.find_parens_start_from_inside(len(code) - 1)
         )
 
-    def test_is_on_function_keyword(self):
+    def test_is_on_function_call_keyword(self):
+        code, annotations = self._annotated_code(annotated_code=dedent("""\
+            myfunc(va
+                  +++
+        """))
+
+        finder = worder.Worder(code)
+        self.assert_equal_annotation(
+            code,
+            annotations,
+            self._make_offset_annotation(code, finder.is_on_function_call_keyword),
+        )
+
+    def test_is_on_function_keyword_partial(self):
         code = "myfunc(va"
         finder = worder.Worder(code)
         self.assertTrue(finder.is_on_function_call_keyword(len(code) - 1))
@@ -474,12 +707,10 @@ class ScopeNameFinderTest(unittest.TestCase):
     def test_modules_after_from_statements(self):
         root_folder = self.project.root
         mod = testutils.create_module(self.project, "mod", root_folder)
-        mod.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod.write(dedent("""\
+            def a_func():
+                pass
+        """))
         code = "from mod import a_func\n"
         scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
@@ -489,12 +720,10 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_renaming_functions_with_from_import_and_parens(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def afunc():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def afunc():
+                pass
+        """))
         code = dedent("""\
             from mod1 import (
                 afunc as func)
@@ -512,12 +741,10 @@ class ScopeNameFinderTest(unittest.TestCase):
         pkg2 = testutils.create_package(self.project, "pkg2", pkg1)
         mod1 = testutils.create_module(self.project, "mod1", pkg1)
         mod2 = testutils.create_module(self.project, "mod2", pkg2)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         code = "from ..mod1 import a_func\n"
         mod2.write(code)
         mod2_scope = self.project.get_pymodule(mod2).get_scope()
@@ -597,12 +824,6 @@ class ScopeNameFinderTest(unittest.TestCase):
 
 
 class LogicalLineFinderTest(unittest.TestCase):
-    def setUp(self):
-        super(LogicalLineFinderTest, self).setUp()
-
-    def tearDown(self):
-        super(LogicalLineFinderTest, self).tearDown()
-
     def _logical_finder(self, code):
         return LogicalLineFinder(SourceLinesAdapter(code))
 
